## What's Changed

- chore: bump version to 0.1.2 and update open_url to open_urls for handling multiple URLs (6838244)

**Full Changelog**: https://github.com/leynier/mcp-sys-bridge/compare/v0.1.1...v0.1.2

